struct DeviceAuthKeyUiInternal {}Trait Implementations
Sourceimpl UserValidationMethod for DeviceAuthKeyUiInternal
impl UserValidationMethod for DeviceAuthKeyUiInternal
Sourcetype PasskeyItem = DeviceAuthKeyRecord
type PasskeyItem = DeviceAuthKeyRecord
The type of the passkey item that can be used to display additional information about the operation to the user.
Sourcefn check_user<'a, 'life0, 'async_trait>(
&'life0 self,
_hint: UiHint<'a, Self::PasskeyItem>,
_presence: bool,
_verification: bool,
) -> Pin<Box<dyn Future<Output = Result<UserCheck, Ctap2Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
fn check_user<'a, 'life0, 'async_trait>(
&'life0 self,
_hint: UiHint<'a, Self::PasskeyItem>,
_presence: bool,
_verification: bool,
) -> Pin<Box<dyn Future<Output = Result<UserCheck, Ctap2Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
Check for the user’s presence and obtain consent for the operation. The operation may
also require the user to be verified. Read more
Sourcefn is_presence_enabled(&self) -> bool
fn is_presence_enabled(&self) -> bool
Indicates whether this type is capable of testing user presence.